==> idf_build_apps-1.0.3.tar.gz: idf_build_apps-1.0.3/CONTRIBUTING.md <==
# Contributions Guide

Please use python 3.7+ for developing, but keep in mind that we need to support all ESP-IDF release versions.

| ESP-IDF Version | Supported Python Versions |
|-----------------|---------------------------|
| 4.1             | 2.7, 3.4+                 |
| 4.2             | 2.7, 3.4+                 |
| 4.3             | 2.7, 3.4+                 |
| 4.4             | 2.7, 3.4+                 |
| 5.0             | 3.7+                      |
| 5.1             | 3.7+                      |
| master          | 3.7+                      |

## Setup the Dev Environment

1. Create virtual environment

    ```shell
    python -m venv venv
    ```

2. Activate the virtual environment

    ```shell
    . ./venv/bin/activate
    ```

3. Install [flit][flit]

    We use [flit][flit] to build the package and install the dependencies.

    ```shell
    pip install flit
    ```

4. Install all dependencies

    All dependencies would be installed, and our package `idf-build-apps` would be installed with editable mode.

    ```shell
    flit install -s
    ```

## Run Testing

We use [pytest][pytest] for testing.

```shell
pytest
```

## Build Documentation

We use [sphinx][sphinx] and [autodoc][autodoc] for generating documentation and API references. Besides, we treat warnings as errors while building the documentation. Please fix them before your commits got merged.

```shell
cd docs && make html SPHINXOPTS="-W"
```

For documentation preview, you may use any browser you prefer. The executable has to be searchable in `PATH`. For example we're using firefox here.

```shell
firefox _build/html/index.html
```

[flit]: https://flit.pypa.io/en/stable/index.html
[pytest]: https://docs.pytest.org/en/stable/contents.html
[sphinx]: https://www.sphinx-doc.org/en/master/
[autodoc]: https://www.sphinx-doc.org/en/master/usage/quickstart.html#autodoc

==> idf_build_apps-2.0.1.tar.gz: idf_build_apps-2.0.1/CONTRIBUTING.md <==
# Contributions Guide

Please use python 3.7+ for developing, but keep in mind that we need to support all ESP-IDF release versions.

| ESP-IDF Version | Supported Python Versions |
|-----------------|---------------------------|
| 4.1             | 2.7, 3.4+                 |
| 4.2             | 2.7, 3.4+                 |
| 4.3             | 2.7, 3.4+                 |
| 4.4             | 2.7, 3.4+                 |
| 5.0             | 3.7+                      |
| 5.1             | 3.7+                      |
| 5.2             | 3.7+                      |
| master          | 3.8+                      |

## Setup the Dev Environment

1. Create virtual environment

    ```shell
    python -m venv venv
    ```

2. Activate the virtual environment

    ```shell
    . ./venv/bin/activate
    ```

3. Install [flit][flit]

    We use [flit][flit] to build the package and install the dependencies.

    ```shell
    pip install flit
    ```

4. Install all dependencies

    All dependencies would be installed, and our package `idf-build-apps` would be installed with editable mode.

    ```shell
    flit install -s
    ```

## Run Testing

We use [pytest][pytest] for testing.

```shell
pytest
```

## Build Documentation

We use [sphinx][sphinx] and [autodoc][autodoc] for generating documentation and API references. Besides, we treat warnings as errors while building the documentation. Please fix them before your commits got merged.

```shell
cd docs && make html
```

For documentation preview, you may use any browser you prefer. The executable has to be searchable in `PATH`. For example we're using firefox here.

```shell
firefox _build/html/index.html
```

[flit]: https://flit.pypa.io/en/stable/index.html
[pytest]: https://docs.pytest.org/en/stable/contents.html
[sphinx]: https://www.sphinx-doc.org/en/master/
[autodoc]: https://www.sphinx-doc.org/en/master/usage/quickstart.html#autodoc
